define(
//begin v1.x content
({
	"findLabel": "Znajdź:",
	"findTooltip": "Wprowadź szukany tekst",
	"replaceLabel": "Zastąp przez:",
	"replaceTooltip": "Wprowadź tekst zastępujący",
	"findReplace": "Znajdź i zastąp",
	"matchCase": "Uwzględnij wielkość liter",
	"matchCaseTooltip": "Uwzględnij wielkość liter",
	"backwards": "Do tyłu",
	"backwardsTooltip": "Wyszukaj tekst wstecz",
	"replaceAllButton": "Zastąp wszystkie",
	"replaceAllButtonTooltip": "Zastąp cały tekst",
	"findButton": "Znajdź",
	"findButtonTooltip": "Znajdź tekst",
	"replaceButton": "Zastąp",
	"replaceButtonTooltip": "Zastąp tekst",
	"replaceDialogText": "Zastąpione wystąpienia: ${0}.",
	"eofDialogText": "Ostatnie wystąpienie: ${0}",
	"eofDialogTextFind": "znaleziono",
	"eofDialogTextReplace": "zastąpiono"
})

//end v1.x content
);
